==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/ReverseEngineering/Gui/Resources/translations/ReverseEngineering_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>Apytikslė plokštuma...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>Gaunati apytikslę plokštumą</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-37"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate B-spline surface...</source>
      <translation type="unfinished">Approximate B-spline surface...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-spline surface</source>
      <translation type="unfinished">Approximate a B-spline surface</translation>
    </message>
    <message>
      <source>Approximate B-Spline surface...</source>
      <translation>Apytikslis B-splaininis paviršius...</translation>
    </message>
    <message>
      <source>Approximate surface...</source>
      <translation type="unfinished">Approximate surface...</translation>
    </message>
    <message>
      <source>Approximate a B-Spline surface</source>
      <translation>Gauti apytikslį B-splaininį paviršių</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location line="+134"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson...</source>
      <translation>Poisson...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson surface reconstruction</source>
      <translation>Puasono paviršiaus atkūrimas</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location line="+32"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Structured point clouds</source>
      <translation>Sudėtiniai aibės taškai</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Triangulation of structured point clouds</source>
      <translation>Sudėtinių taškų aibių trianguliacija</translation>
    </message>
    <message>
      <source>View triangulation</source>
      <translation type="unfinished">View triangulation</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <source>Fit B-Spline surface</source>
      <translation>Priderinti B-splaininį paviršių</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="+14"/>
      <source>Fit B-spline surface</source>
      <translation type="unfinished">Fit B-spline surface</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>u-Direction</source>
      <translation>u kryptis</translation>
    </message>
    <message>
      <location line="+6"/>
      <location line="+67"/>
      <source>Degree</source>
      <translation>Eilė</translation>
    </message>
    <message>
      <location line="-38"/>
      <location line="+67"/>
      <source>Control points</source>
      <translation>Valdantieji taškai</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>v-Direction</source>
      <translation>v kryptis</translation>
    </message>
    <message>
      <location line="+67"/>
      <source>Settings</source>
      <translation type="unfinished">Settings</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Iterations</source>
      <translation>Žingsniai</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Size factor</source>
      <translation>Dydžio koeficientas</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Smoothing</source>
      <translation>Glodinimas</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Total Weight</source>
      <translation>Bendras svoris</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Length of gradient</source>
      <translation>Gradiento ilgis</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Bending energy</source>
      <translation>Lenkimo energija</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Curvature variation</source>
      <translation>Kreivio kitimas</translation>
    </message>
    <message>
      <location line="+32"/>
      <source>User-defined u/v directions</source>
      <translation>Vartotojo apibrėžtos u/v kryptys</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="+146"/>
      <source>Wrong selection</source>
      <translation>Netinkama pasirinktis</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>Prašome pasirinkti vieną padėjimo objektą gauti vietos orientacijai.</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Input error</source>
      <translation type="unfinished">Input error</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="+14"/>
      <source>Poisson</source>
      <translation>Poisson</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Parameters</source>
      <translation>Dydžiai</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Octree depth</source>
      <translation>Aštuntainio medžio gylis</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Solver divide</source>
      <translation>Sprendiklio dalinimas</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Samples per node</source>
      <translation>Atskaitų kiekis mazgui</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="+109"/>
      <source>Input error</source>
      <translation type="unfinished">Input error</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="-159"/>
      <location line="+135"/>
      <source>Wrong selection</source>
      <translation>Netinkama pasirinktis</translation>
    </message>
    <message>
      <location line="-134"/>
      <location line="+135"/>
      <source>Please select a single point cloud.</source>
      <translation>Prašome pasirinkti vieną taškų aibę.</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location line="+55"/>
      <source>View triangulation failed</source>
      <translation>Trianguliacijos rodymas sutriko</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/ReverseEngineering/Gui/Resources/translations/ReverseEngineering_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt" sourcelanguage="en">
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate plane...</source>
      <translation>Apytikslė plokštuma...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a plane</source>
      <translation>Gaunati apytikslę plokštumą</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location line="-37"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate B-spline surface...</source>
      <translation>Gauti apytikslį B-splaininį paviršių...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Approximate a B-spline surface</source>
      <translation>Gauti apytikslį B-splaininį paviršių</translation>
    </message>
    <message>
      <source>Approximate B-Spline surface...</source>
      <translation>Apytikslis B-splaininis paviršius...</translation>
    </message>
    <message>
      <source>Approximate surface...</source>
      <translation type="unfinished">Approximate surface...</translation>
    </message>
    <message>
      <source>Approximate a B-Spline surface</source>
      <translation>Gauti apytikslį B-splaininį paviršių</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location line="+134"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson...</source>
      <translation>Poisson...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Poisson surface reconstruction</source>
      <translation>Puasono paviršiaus atkūrimas</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location line="+32"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Structured point clouds</source>
      <translation>Sudėtiniai aibės taškai</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Triangulation of structured point clouds</source>
      <translation>Sudėtinių taškų aibių trianguliacija</translation>
    </message>
    <message>
      <source>View triangulation</source>
      <translation type="unfinished">View triangulation</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <source>Fit B-Spline surface</source>
      <translation>Priderinti B-splaininį paviršių</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="+14"/>
      <source>Fit B-spline surface</source>
      <translation>Priderinti B-splaininį paviršių</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>u-Direction</source>
      <translation>u kryptis</translation>
    </message>
    <message>
      <location line="+6"/>
      <location line="+67"/>
      <source>Degree</source>
      <translation>Eilė</translation>
    </message>
    <message>
      <location line="-38"/>
      <location line="+67"/>
      <source>Control points</source>
      <translation>Valdantieji taškai</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>v-Direction</source>
      <translation>v kryptis</translation>
    </message>
    <message>
      <location line="+67"/>
      <source>Settings</source>
      <translation type="unfinished">Settings</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Iterations</source>
      <translation>Žingsniai</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Size factor</source>
      <translation>Dydžio koeficientas</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Smoothing</source>
      <translation>Glodinimas</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Total Weight</source>
      <translation>Bendras svoris</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Length of gradient</source>
      <translation>Perėjimo ilgis</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Bending energy</source>
      <translation>Lenkimo energija</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Curvature variation</source>
      <translation>Kreivio kitimas</translation>
    </message>
    <message>
      <location line="+32"/>
      <source>User-defined u/v directions</source>
      <translation>Vartotojo apibrėžtos u/v kryptys</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="+146"/>
      <source>Wrong selection</source>
      <translation>Netinkama pasirinktis</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>Prašome pasirinkti vieną dėstymo objektą gauti vietos orientacijai.</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Input error</source>
      <translation type="unfinished">Input error</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="+14"/>
      <source>Poisson</source>
      <translation>Poisson</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Parameters</source>
      <translation>Dydžiai</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Octree depth</source>
      <translation>Aštuntainio medžio gylis</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Solver divide</source>
      <translation>Sprendiklio dalinimas</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Samples per node</source>
      <translation>Atskaitų kiekis mazgui</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="+109"/>
      <source>Input error</source>
      <translation type="unfinished">Input error</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="-159"/>
      <location line="+135"/>
      <source>Wrong selection</source>
      <translation>Netinkama pasirinktis</translation>
    </message>
    <message>
      <location line="-134"/>
      <location line="+135"/>
      <source>Please select a single point cloud.</source>
      <translation>Prašome pasirinkti vieną taškų aibę.</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location line="+55"/>
      <source>View triangulation failed</source>
      <translation>Trianguliacijos rodymas sutriko</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Reverse Engineering</source>
      <translation>Apgrąžos inžinerija</translation>
    </message>
  </context>
</TS>
